@@ -1,11 +1,16 @@
+from __future__ import print_function
+from __future__ import absolute_import
+from future import standard_library
+standard_library.install_aliases()
+from builtins import str
 import argparse
 import os
 import subprocess
-import urllib2
-import utils
+import urllib.request, urllib.error, urllib.parse
+from . import utils
 import sys
 from shutil import copyfile
-from agent import run_agent
+from .agent import run_agent
 from time import sleep
 
 
@@ -85,7 +90,8 @@ def install_and_init_agent(token, account_id, custom_host, modules_path):
         create_agent_local_folders()
         handle_base_modules(dirname, modules_path)
         handle_yml_file(dirname)
-        handle_credentials(account_id, script_full_path, spotinst_agent_path, token, custom_host)
+        handle_credentials(account_id, script_full_path, spotinst_agent_path, token)
+        handle_custom_host(custom_host)
         handle_agent_path(spotinst_agent_path)
         runscript = subprocess.Popen(script_full_path)
         runscript.wait()
@@ -109,7 +115,7 @@ def handle_cloud_provider(cloud_provider, instance_details_path):
         os.chmod(full_path, 0o644)
         return True
     except IOError:
-        print "Unable to create /etc/spotinst/cloud_provider.txt"
+        print("Unable to create /etc/spotinst/cloud_provider.txt")
         if cloud_provider_file is not None:
             cloud_provider_file.close()
         return False
@@ -145,15 +151,12 @@ def handle_yml_file(dirname):
         copyfile(default_agent_yml, default_yml_destination)
 
 
-def handle_credentials(account_id, script_full_path, spotinst_agent_path, token, host):
+def handle_credentials(account_id, script_full_path, spotinst_agent_path, token):
     if token is not None:
         print ("Creating Spotinst credentials directory")
 
-        if host is None:
-            #if the customer didn't supply custom host set the default
-            host = 'api.spotinst.io'
         creds_file, creds_path = create_creds_file()
-        write_creds_path(account_id, creds_file, token, host)
+        write_creds_path(account_id, creds_file, token)
         os.chmod(creds_path, 0o777)
 
     else:
@@ -161,18 +164,20 @@ def handle_credentials(account_id, script_full_path, spotinst_agent_path, token,
         creds = utils.retrieve_creds()
         token = creds["token"]
         account_id = creds["account_id"]
-        host = creds["host"]
     os.putenv("SPOTINST_TOKEN", token)
     os.putenv("SPOTINST_ACCOUNT_ID", account_id)
-    os.putenv("CUSTOM_HOST", host)
     os.putenv("SPOTINST_AGENT_PATH", spotinst_agent_path)
     os.chmod(script_full_path, 0o777)
 
-def write_creds_path(account_id, creds_file, token, host):
+def handle_custom_host(custom_host):
+    if custom_host is not None:
+        os.putenv("CUSTOM_HOST", custom_host)
+
+def write_creds_path(account_id, creds_file, token):
     if account_id is not None:
-        creds_file.write('token = ' + token + '\n' + 'account_id = ' + account_id + '\n' + 'host = ' + host)
+        creds_file.write('token = ' + token + '\n' + 'account_id = ' + account_id)
     else:
-        creds_file.write('token = ' + token + '\n' + 'host = ' + host)
+        creds_file.write('token = ' + token)
 
 
 def create_creds_file():
@@ -234,6 +239,7 @@ def install_collector(collector_name, modules_path, s3_base_collectors_link):
     print ("adding collector " + collector_name)
     try:
         handle_prerequisites(s3_base_collectors_link, collector_name)
+        print("post handle_prerequisites")
         get_collector_files(collector_name, modules_path, s3_base_collectors_link)
 
     except Exception as e:
@@ -241,8 +247,8 @@ def install_collector(collector_name, modules_path, s3_base_collectors_link):
 
 
 def get_worker_files(modules_path, s3_base_workers_link, worker_name):
-    py_response = urllib2.urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.py')
-    yml_response = urllib2.urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.yml')
+    py_response = urllib.request.urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.py')
+    yml_response = urllib.request.urlopen(s3_base_workers_link + '/' + worker_name + '/' + worker_name + '.yml')
 
     with open(modules_path + '/' + worker_name + '.py', 'wb') as worker:
         worker.write(py_response.read())
@@ -252,17 +258,20 @@ def get_worker_files(modules_path, s3_base_workers_link, worker_name):
 
 def get_collector_files(collector_name, modules_path, s3_base_collectors_link):
     with open(modules_path + '/' + collector_name + '.py', 'wb') as collector:
-        response = urllib2.urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.py')
+        response = urllib.request.urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.py')
         collector.write(response.read())
     with open(modules_path + '/' + collector_name + '.yml', 'wb') as collector_cfg:
-        response = urllib2.urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.yml')
+        response = urllib.request.urlopen(s3_base_collectors_link + '/' + collector_name + '/' + collector_name + '.yml')
         collector_cfg.write(response.read())
 
 
 def handle_prerequisites(s3_base_module_link, module_name):
     try:
-        response = urllib2.urlopen(s3_base_module_link + '/' + module_name + '/' + module_name + '.req')
+        print ("1")
+        response = urllib.request.urlopen(s3_base_module_link + '/' + module_name + '/' + module_name + '.req')
+        print ("2")
         requirements_file = response.read()
+        print ("3")
         requirements_names = requirements_file.split("\n")
         print ("This module requires the following packages to be installed:")
         for requirement in requirements_names:
